__version__ = "0.2.0"

import hashlib
from collections import Counter
from re import findall
from string import punctuation

import requests


def check_password(password: str) -> int:
    sha1 = hashlib.sha1(password.encode("utf-8")).hexdigest()

    response = requests.get(f"https://api.pwnedpasswords.com/range/{sha1[:5]}")

    hash_suffix_list = [x.split(":") for x in response.text.splitlines(False)]

    try:
        count = [count for suffix,
                 count in hash_suffix_list if sha1.endswith(suffix.lower())][0]
    except IndexError:
        return 0

    return int(count)


class PasswordRequirements:
    def __init__(self, *, min_length: int = 0, min_digits: int = 0, min_special: int = 0):
        self.min_length = min_length
        self.min_digits = min_digits
        self.min_special = min_special

    def check(self, password: str):
        if len(password) < self.min_length:
            return False

        digits = len(findall(r"\d", password))
        if digits < self.min_digits:
            return False

        special_chars = sum(v for k, v in Counter(password).items() if k in punctuation)
        if special_chars < self.min_special:
            return False

        return True



import codecs
import os.path

import setuptools


def read(rel_path):
    here = os.path.abspath(os.path.dirname(__file__))
    with codecs.open(os.path.join(here, rel_path), 'r') as fp:
        return fp.read()


def get_version(rel_path):
    for line in read(rel_path).splitlines():
        if line.startswith('__version__'):
            delim = '"' if '"' in line else "'"
            return line.split(delim)[1]
    else:
        raise RuntimeError("Unable to find version string.")


with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="passwd",
    version=get_version("passwd/__init__.py"),
    author="Benjamin Soyka",
    author_email="bensoyka@icloud.com",
    description="Assorted utilities for gracefully handling and generating passwords",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/bsoyka/passwd",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
    python_requires='>=3.6',
    project_urls={
        "Documentation": "https://github.com/bsoyka/passwd/wiki",
        "Changelog": "https://github.com/bsoyka/passwd/blob/master/CHANGELOG.md"
    }
)
